@@ -220,8 +220,8 @@ impl<'a, W: Write> Serializer for &'a mut Encoder<W> {
         Err(Error::Unsupported("f64"))
     }
 
-    fn serialize_char(self, _: char) -> Result<Self::Ok, Self::Error> {
-        Err(Error::Unsupported("char"))
+    fn serialize_char(self, v: char) -> Result<Self::Ok, Self::Error> {
+        self.serialize_str(&v.to_string())
     }
 
     fn serialize_str(self, v: &str) -> Result<Self::Ok, Self::Error> {
@@ -827,6 +827,11 @@ mod test {
         test_encode!(0.0, b"");
     }
 
+    #[test]
+    fn encode_char() {
+        test_encode!('a', b"1:a");
+    }
+
     #[test]
     fn encode_bytes() {
         test_encode!(Bytes::new(b"hello"), b"5:hello");
